.. include:: ../README.md
    :parser: myst_parser.sphinx_

To get to know the library, please proceed to the :doc:`notebooks/intro` tutorial.

.. toctree::
   :maxdepth: 2
   :hidden:

   Welcome <self>

.. toctree::
   :maxdepth: 1
   :hidden:
   :numbered:
   :caption: User Guide

   notebooks/intro
   notebooks/combinations
   notebooks/nested
   notebooks/models
   notebooks/example

.. toctree::
   :maxdepth: 1
   :hidden:
   :caption: Extra Material

   changelog
   contributing
